@@ -4,11 +4,13 @@
 # See top-level LICENSE file for more information
 
 import copy
+import datetime
 import os
 import shutil
 import subprocess
 import tempfile
 
+import dulwich.objects
 import dulwich.repo
 import pytest
 
@@ -16,6 +18,8 @@ import swh.loader.git.converters as converters
 from swh.model.hashutil import bytehex_to_hash, hash_to_bytehex, hash_to_bytes
 from swh.model.model import (
     Content,
+    Directory,
+    DirectoryEntry,
     ObjectType,
     Person,
     Release,
@@ -214,6 +218,33 @@ class TestConverters:
         with pytest.raises(converters.HashMismatch):
             converters.dulwich_tree_to_directory(tree)
 
+    def test_tree_perms(self):
+        entries = [
+            (b"blob_100644", 0o100644, "file"),
+            (b"blob_100664", 0o100664, "file"),
+            (b"blob_100666", 0o100666, "file"),
+            (b"blob_120000", 0o120000, "file"),
+            (b"commit_160644", 0o160644, "rev"),
+            (b"commit_160664", 0o160664, "rev"),
+            (b"commit_160666", 0o160666, "rev"),
+            (b"commit_normal", 0o160000, "rev"),
+            (b"tree_040644", 0o040644, "dir"),
+            (b"tree_040664", 0o040664, "dir"),
+            (b"tree_040666", 0o040666, "dir"),
+            (b"tree_normal", 0o040000, "dir"),
+        ]
+
+        tree = dulwich.objects.Tree()
+        for (name, mode, _) in entries:
+            tree.add(name, mode, b"00" * 20)
+
+        assert converters.dulwich_tree_to_directory(tree) == Directory(
+            entries=tuple(
+                DirectoryEntry(type=type, perms=perms, name=name, target=b"\x00" * 20)
+                for (name, perms, type) in entries
+            )
+        )
+
     def test_commit_to_revision(self):
         sha1 = b"9768d0b576dbaaecd80abedad6dfd0d72f1476da"
 
@@ -413,8 +444,6 @@ class TestConverters:
         target = b"641fb6e08ddb2e4fd096dcf18e80b894bf7e25ce"
         message = b"some release message"
 
-        import datetime
-
         date = datetime.datetime(2007, 12, 5, tzinfo=datetime.timezone.utc).timestamp()
 
         tag = SWHTag(
@@ -497,6 +526,52 @@ class TestConverters:
 
         assert actual_release == expected_release
 
+    def test_dulwich_tag_to_release_author_zero_date(self):
+        # to reproduce bug T815 (fixed)
+        sha = hash_to_bytes("6cc1deff5cdcd853428bb63b937f43dd2566c36f")
+        tagger = b"hey dude <hello@mail.org>"
+        target = b"641fb6e08ddb2e4fd096dcf18e80b894bf7e25ce"
+        message = b"some release message"
+        date = datetime.datetime(1970, 1, 1, tzinfo=datetime.timezone.utc).timestamp()
+        tag = SWHTag(
+            sha=sha,
+            name=b"blah",
+            type_name=b"tag",
+            target=target,
+            target_type=b"commit",
+            message=message,
+            signature=None,
+            tagger=tagger,
+            tag_time=date,
+            tag_timezone=0,
+        )
+
+        # when
+        actual_release = converters.dulwich_tag_to_release(tag)
+
+        # then
+        expected_release = Release(
+            author=Person(
+                email=b"hello@mail.org",
+                fullname=b"hey dude <hello@mail.org>",
+                name=b"hey dude",
+            ),
+            date=TimestampWithTimezone(
+                negative_utc=False,
+                offset=0,
+                timestamp=Timestamp(seconds=0, microseconds=0,),
+            ),
+            id=sha,
+            message=message,
+            metadata=None,
+            name=b"blah",
+            synthetic=False,
+            target=hash_to_bytes(target.decode()),
+            target_type=ObjectType.REVISION,
+        )
+
+        assert actual_release == expected_release
+
     def test_dulwich_tag_to_release_signature(self):
         target = b"641fb6e08ddb2e4fd096dcf18e80b894bf7e25ce"
         message = b"some release message"
